@@ -72,13 +72,15 @@ def setup(app: flask.Flask, config: typing.Dict[str, typing.Any], **kwargs) -> A
     """ Simple setup function.
 
     :param flask.flask app: The Flask app to configure with Authl.
+
     :param dict config: Configuration values for the Authl instance; see
         :py:func:`authl.from_config`
+
     :param kwargs: Additional arguments to pass along to the
         :py:class:`AuthlFlask` constructor
 
-    Returns the configured :py:class:`authl.Authl` instance. Note that if you
-    want the :py:class:`AuthlFlask` instance you should instantiate that directly.
+    :returns: The configured :py:class:`authl.Authl` instance. Note that if you
+        want the :py:class:`AuthlFlask` instance you should instantiate that directly.
 
     """
     return AuthlFlask(app, config, **kwargs).authl
@@ -91,7 +93,7 @@ def load_template(filename: str) -> str:
 
     Raises `FileNotFoundError` on no such template
 
-    Returns the contents of the template.
+    :returns: the contents of the template.
     """
     return utils.read_file(os.path.join(os.path.dirname(__file__), 'flask_templates', filename))
 
@@ -354,12 +356,13 @@ class AuthlFlask:
 
     def render_login_form(self, destination: str, error: typing.Optional[str] = None):
         """
-        Renders the login form from an alternate route, for example if a page
-        requires login to be seen.
+        Renders the login form. This might be called by the Flask app if, for
+        example, a page requires login to be seen.
 
-        :param str destination: The redirection destination
-        :param str error: Any error to display on the login form
+        :param str destination: The redirection destination, as a full path
+            (e.g. ``'/path/to/view'``)
 
+        :param str error: Any error message to display on the login form
         """
         login_url = flask.url_for(self.login_name,
                                   redir=_redir_dest_to_path(destination or '/'),
@@ -370,7 +373,7 @@ class AuthlFlask:
         id_url = self._session.get(self._prefill_key, '')
         LOGGER.debug('id_url: %s', id_url)
 
-        render_args = {
+        render_args: typing.Dict[str, typing.Any] = {
             'login_url': login_url,
             'test_url': test_url,
             'auth': self.authl,
@@ -402,6 +405,7 @@ class AuthlFlask:
 
         me_url = request.form.get('me', request.args.get('me'))
         if me_url:
+            # Process the login request
             self._session[self._prefill_key] = me_url
             handler, hid, id_url = self.authl.get_handler_for_url(me_url)
             if handler:
@@ -415,7 +419,7 @@ class AuthlFlask:
                     dest))
 
             # No handler found, so provide error message to login_form
-            error = 'Unknown authorization method'
+            error = 'Unknown authentication method'
 
         return self.render_login_form(destination=dest, error=error)
 
